<a id="aea.helpers.http_requests"></a>

# aea.helpers.http`_`requests

Wrapper over requests library.

<a id="aea.helpers.http_requests.add_default_timeout"></a>

#### add`_`default`_`timeout

```python
def add_default_timeout(fn: Callable, timeout: float) -> Callable
```

Add default timeout for requests methods.

<a id="aea.helpers.http_requests.ConnectionError"></a>

#### ConnectionError

pylint: disable=redefined-builtin

